==> php-nesbot-carbon_2.32.2.orig.tar.xz: php-nesbot-carbon-2.32.2/tests/Localization/LzhTest.php <==
<?php
declare(strict_types=1);

/**
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace Tests\Localization;

class LzhTest extends LocalizationTestCase
{
    const LOCALE = 'lzh'; // Literary Chinese

    const CASES = [
        // Carbon::parse('2018-01-04 00:00:00')->addDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Tomorrow at 12:00 朝',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        '週六 at 12:00 朝',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(3)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        '週日 at 12:00 朝',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(4)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        '週一 at 12:00 朝',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(5)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        '週二 at 12:00 朝',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        '週三 at 12:00 朝',
        // Carbon::parse('2018-01-05 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-05 00:00:00'))
        '週四 at 12:00 朝',
        // Carbon::parse('2018-01-06 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-06 00:00:00'))
        '週五 at 12:00 朝',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        '週二 at 12:00 朝',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(3)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        '週三 at 12:00 朝',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(4)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        '週四 at 12:00 朝',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(5)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        '週五 at 12:00 朝',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        '週六 at 12:00 朝',
        // Carbon::now()->subDays(2)->calendar()
        'Last 週日 at 8:49 暮',
        // Carbon::parse('2018-01-04 00:00:00')->subHours(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Yesterday at 10:00 暮',
        // Carbon::parse('2018-01-04 12:00:00')->subHours(2)->calendar(Carbon::parse('2018-01-04 12:00:00'))
        'Today at 10:00 朝',
        // Carbon::parse('2018-01-04 00:00:00')->addHours(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Today at 2:00 朝',
        // Carbon::parse('2018-01-04 23:00:00')->addHours(2)->calendar(Carbon::parse('2018-01-04 23:00:00'))
        'Tomorrow at 1:00 朝',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        '週二 at 12:00 朝',
        // Carbon::parse('2018-01-08 00:00:00')->subDay()->calendar(Carbon::parse('2018-01-08 00:00:00'))
        'Yesterday at 12:00 朝',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Yesterday at 12:00 朝',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last 週二 at 12:00 朝',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(3)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last 週一 at 12:00 朝',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(4)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last 週日 at 12:00 朝',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(5)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last 週六 at 12:00 朝',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last 週五 at 12:00 朝',
        // Carbon::parse('2018-01-03 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-03 00:00:00'))
        'Last 週四 at 12:00 朝',
        // Carbon::parse('2018-01-02 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-02 00:00:00'))
        'Last 週三 at 12:00 朝',
        // Carbon::parse('2018-01-07 00:00:00')->subDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'Last 週五 at 12:00 朝',
        // Carbon::parse('2018-01-01 00:00:00')->isoFormat('Qo Mo Do Wo wo')
        '1st 1st 1st 1st 1st',
        // Carbon::parse('2018-01-02 00:00:00')->isoFormat('Do wo')
        '2nd 1st',
        // Carbon::parse('2018-01-03 00:00:00')->isoFormat('Do wo')
        '3rd 1st',
        // Carbon::parse('2018-01-04 00:00:00')->isoFormat('Do wo')
        '4th 1st',
        // Carbon::parse('2018-01-05 00:00:00')->isoFormat('Do wo')
        '5th 1st',
        // Carbon::parse('2018-01-06 00:00:00')->isoFormat('Do wo')
        '6th 1st',
        // Carbon::parse('2018-01-07 00:00:00')->isoFormat('Do wo')
        '7th 2nd',
        // Carbon::parse('2018-01-11 00:00:00')->isoFormat('Do wo')
        '11th 2nd',
        // Carbon::parse('2018-02-09 00:00:00')->isoFormat('DDDo')
        '40th',
        // Carbon::parse('2018-02-10 00:00:00')->isoFormat('DDDo')
        '41st',
        // Carbon::parse('2018-04-10 00:00:00')->isoFormat('DDDo')
        '100th',
        // Carbon::parse('2018-02-10 00:00:00', 'Europe/Paris')->isoFormat('h:mm a z')
        '12:00 朝 CET',
        // Carbon::parse('2018-02-10 00:00:00')->isoFormat('h:mm A, h:mm a')
        '12:00 朝, 12:00 朝',
        // Carbon::parse('2018-02-10 01:30:00')->isoFormat('h:mm A, h:mm a')
        '1:30 朝, 1:30 朝',
        // Carbon::parse('2018-02-10 02:00:00')->isoFormat('h:mm A, h:mm a')
        '2:00 朝, 2:00 朝',
        // Carbon::parse('2018-02-10 06:00:00')->isoFormat('h:mm A, h:mm a')
        '6:00 朝, 6:00 朝',
        // Carbon::parse('2018-02-10 10:00:00')->isoFormat('h:mm A, h:mm a')
        '10:00 朝, 10:00 朝',
        // Carbon::parse('2018-02-10 12:00:00')->isoFormat('h:mm A, h:mm a')
        '12:00 暮, 12:00 暮',
        // Carbon::parse('2018-02-10 17:00:00')->isoFormat('h:mm A, h:mm a')
        '5:00 暮, 5:00 暮',
        // Carbon::parse('2018-02-10 21:30:00')->isoFormat('h:mm A, h:mm a')
        '9:30 暮, 9:30 暮',
        // Carbon::parse('2018-02-10 23:00:00')->isoFormat('h:mm A, h:mm a')
        '11:00 暮, 11:00 暮',
        // Carbon::parse('2018-01-01 00:00:00')->ordinal('hour')
        '0th',
        // Carbon::now()->subSeconds(1)->diffForHumans()
        '1 楚 ago',
        // Carbon::now()->subSeconds(1)->diffForHumans(null, false, true)
        '1 楚 ago',
        // Carbon::now()->subSeconds(2)->diffForHumans()
        '2 楚 ago',
        // Carbon::now()->subSeconds(2)->diffForHumans(null, false, true)
        '2 楚 ago',
        // Carbon::now()->subMinutes(1)->diffForHumans()
        '1 點 ago',
        // Carbon::now()->subMinutes(1)->diffForHumans(null, false, true)
        '1 點 ago',
        // Carbon::now()->subMinutes(2)->diffForHumans()
        '2 點 ago',
        // Carbon::now()->subMinutes(2)->diffForHumans(null, false, true)
        '2 點 ago',
        // Carbon::now()->subHours(1)->diffForHumans()
        '1 氧 ago',
        // Carbon::now()->subHours(1)->diffForHumans(null, false, true)
        '1 氧 ago',
        // Carbon::now()->subHours(2)->diffForHumans()
        '2 氧 ago',
        // Carbon::now()->subHours(2)->diffForHumans(null, false, true)
        '2 氧 ago',
        // Carbon::now()->subDays(1)->diffForHumans()
        '1 日(曆法) ago',
        // Carbon::now()->subDays(1)->diffForHumans(null, false, true)
        '1 日(曆法) ago',
        // Carbon::now()->subDays(2)->diffForHumans()
        '2 日(曆法) ago',
        // Carbon::now()->subDays(2)->diffForHumans(null, false, true)
        '2 日(曆法) ago',
        // Carbon::now()->subWeeks(1)->diffForHumans()
        '1 星期 ago',
        // Carbon::now()->subWeeks(1)->diffForHumans(null, false, true)
        '1 星期 ago',
        // Carbon::now()->subWeeks(2)->diffForHumans()
        '2 星期 ago',
        // Carbon::now()->subWeeks(2)->diffForHumans(null, false, true)
        '2 星期 ago',
        // Carbon::now()->subMonths(1)->diffForHumans()
        '1 月 ago',
        // Carbon::now()->subMonths(1)->diffForHumans(null, false, true)
        '1 月 ago',
        // Carbon::now()->subMonths(2)->diffForHumans()
        '2 月 ago',
        // Carbon::now()->subMonths(2)->diffForHumans(null, false, true)
        '2 月 ago',
        // Carbon::now()->subYears(1)->diffForHumans()
        '1 夏 ago',
        // Carbon::now()->subYears(1)->diffForHumans(null, false, true)
        '1 夏 ago',
        // Carbon::now()->subYears(2)->diffForHumans()
        '2 夏 ago',
        // Carbon::now()->subYears(2)->diffForHumans(null, false, true)
        '2 夏 ago',
        // Carbon::now()->addSecond()->diffForHumans()
        '1 楚 from now',
        // Carbon::now()->addSecond()->diffForHumans(null, false, true)
        '1 楚 from now',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now())
        '1 楚 after',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), false, true)
        '1 楚 after',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond())
        '1 楚 before',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond(), false, true)
        '1 楚 before',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), true)
        '1 楚',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), true, true)
        '1 楚',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond()->addSecond(), true)
        '2 楚',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond()->addSecond(), true, true)
        '2 楚',
        // Carbon::now()->addSecond()->diffForHumans(null, false, true, 1)
        '1 楚 from now',
        // Carbon::now()->addMinute()->addSecond()->diffForHumans(null, true, false, 2)
        '1 點 1 楚',
        // Carbon::now()->addYears(2)->addMonths(3)->addDay()->addSecond()->diffForHumans(null, true, true, 4)
        '2 夏 3 月 1 日(曆法) 1 楚',
        // Carbon::now()->addYears(3)->diffForHumans(null, null, false, 4)
        '3 夏 from now',
        // Carbon::now()->subMonths(5)->diffForHumans(null, null, true, 4)
        '5 月 ago',
        // Carbon::now()->subYears(2)->subMonths(3)->subDay()->subSecond()->diffForHumans(null, null, true, 4)
        '2 夏 3 月 1 日(曆法) 1 楚 ago',
        // Carbon::now()->addWeek()->addHours(10)->diffForHumans(null, true, false, 2)
        '1 星期 10 氧',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
        '1 星期 6 日(曆法)',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
        '1 星期 6 日(曆法)',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(["join" => true, "parts" => 2])
        '1 星期 and 6 日(曆法) from now',
        // Carbon::now()->addWeeks(2)->addHour()->diffForHumans(null, true, false, 2)
        '2 星期 1 氧',
        // Carbon::now()->addHour()->diffForHumans(["aUnit" => true])
        '1 氧 from now',
        // CarbonInterval::days(2)->forHumans()
        '2 日(曆法)',
        // CarbonInterval::create('P1DT3H')->forHumans(true)
        '1 日(曆法) 3 氧',
    ];
}

==> php-nesbot-carbon_2.65.0.orig.tar.xz: php-nesbot-carbon-2.65.0/tests/Localization/LzhTest.php <==
<?php

declare(strict_types=1);

/**
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Tests\Localization;

/**
 * @group localization
 */
class LzhTest extends LocalizationTestCase
{
    public const LOCALE = 'lzh'; // Literary Chinese

    public const CASES = [
        // Carbon::parse('2018-01-04 00:00:00')->addDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Tomorrow at 12:00 朝',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        '週六 at 12:00 朝',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(3)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        '週日 at 12:00 朝',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(4)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        '週一 at 12:00 朝',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(5)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        '週二 at 12:00 朝',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        '週三 at 12:00 朝',
        // Carbon::parse('2018-01-05 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-05 00:00:00'))
        '週四 at 12:00 朝',
        // Carbon::parse('2018-01-06 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-06 00:00:00'))
        '週五 at 12:00 朝',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        '週二 at 12:00 朝',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(3)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        '週三 at 12:00 朝',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(4)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        '週四 at 12:00 朝',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(5)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        '週五 at 12:00 朝',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        '週六 at 12:00 朝',
        // Carbon::now()->subDays(2)->calendar()
        'Last 週日 at 8:49 暮',
        // Carbon::parse('2018-01-04 00:00:00')->subHours(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Yesterday at 10:00 暮',
        // Carbon::parse('2018-01-04 12:00:00')->subHours(2)->calendar(Carbon::parse('2018-01-04 12:00:00'))
        'Today at 10:00 朝',
        // Carbon::parse('2018-01-04 00:00:00')->addHours(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Today at 2:00 朝',
        // Carbon::parse('2018-01-04 23:00:00')->addHours(2)->calendar(Carbon::parse('2018-01-04 23:00:00'))
        'Tomorrow at 1:00 朝',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        '週二 at 12:00 朝',
        // Carbon::parse('2018-01-08 00:00:00')->subDay()->calendar(Carbon::parse('2018-01-08 00:00:00'))
        'Yesterday at 12:00 朝',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Yesterday at 12:00 朝',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last 週二 at 12:00 朝',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(3)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last 週一 at 12:00 朝',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(4)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last 週日 at 12:00 朝',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(5)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last 週六 at 12:00 朝',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last 週五 at 12:00 朝',
        // Carbon::parse('2018-01-03 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-03 00:00:00'))
        'Last 週四 at 12:00 朝',
        // Carbon::parse('2018-01-02 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-02 00:00:00'))
        'Last 週三 at 12:00 朝',
        // Carbon::parse('2018-01-07 00:00:00')->subDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'Last 週五 at 12:00 朝',
        // Carbon::parse('2018-01-01 00:00:00')->isoFormat('Qo Mo Do Wo wo')
        '1st 1st 1st 1st 1st',
        // Carbon::parse('2018-01-02 00:00:00')->isoFormat('Do wo')
        '2nd 1st',
        // Carbon::parse('2018-01-03 00:00:00')->isoFormat('Do wo')
        '3rd 1st',
        // Carbon::parse('2018-01-04 00:00:00')->isoFormat('Do wo')
        '4th 1st',
        // Carbon::parse('2018-01-05 00:00:00')->isoFormat('Do wo')
        '5th 1st',
        // Carbon::parse('2018-01-06 00:00:00')->isoFormat('Do wo')
        '6th 1st',
        // Carbon::parse('2018-01-07 00:00:00')->isoFormat('Do wo')
        '7th 2nd',
        // Carbon::parse('2018-01-11 00:00:00')->isoFormat('Do wo')
        '11th 2nd',
        // Carbon::parse('2018-02-09 00:00:00')->isoFormat('DDDo')
        '40th',
        // Carbon::parse('2018-02-10 00:00:00')->isoFormat('DDDo')
        '41st',
        // Carbon::parse('2018-04-10 00:00:00')->isoFormat('DDDo')
        '100th',
        // Carbon::parse('2018-02-10 00:00:00', 'Europe/Paris')->isoFormat('h:mm a z')
        '12:00 朝 CET',
        // Carbon::parse('2018-02-10 00:00:00')->isoFormat('h:mm A, h:mm a')
        '12:00 朝, 12:00 朝',
        // Carbon::parse('2018-02-10 01:30:00')->isoFormat('h:mm A, h:mm a')
        '1:30 朝, 1:30 朝',
        // Carbon::parse('2018-02-10 02:00:00')->isoFormat('h:mm A, h:mm a')
        '2:00 朝, 2:00 朝',
        // Carbon::parse('2018-02-10 06:00:00')->isoFormat('h:mm A, h:mm a')
        '6:00 朝, 6:00 朝',
        // Carbon::parse('2018-02-10 10:00:00')->isoFormat('h:mm A, h:mm a')
        '10:00 朝, 10:00 朝',
        // Carbon::parse('2018-02-10 12:00:00')->isoFormat('h:mm A, h:mm a')
        '12:00 暮, 12:00 暮',
        // Carbon::parse('2018-02-10 17:00:00')->isoFormat('h:mm A, h:mm a')
        '5:00 暮, 5:00 暮',
        // Carbon::parse('2018-02-10 21:30:00')->isoFormat('h:mm A, h:mm a')
        '9:30 暮, 9:30 暮',
        // Carbon::parse('2018-02-10 23:00:00')->isoFormat('h:mm A, h:mm a')
        '11:00 暮, 11:00 暮',
        // Carbon::parse('2018-01-01 00:00:00')->ordinal('hour')
        '0th',
        // Carbon::now()->subSeconds(1)->diffForHumans()
        '1 楚 ago',
        // Carbon::now()->subSeconds(1)->diffForHumans(null, false, true)
        '1 楚 ago',
        // Carbon::now()->subSeconds(2)->diffForHumans()
        '2 楚 ago',
        // Carbon::now()->subSeconds(2)->diffForHumans(null, false, true)
        '2 楚 ago',
        // Carbon::now()->subMinutes(1)->diffForHumans()
        '1 點 ago',
        // Carbon::now()->subMinutes(1)->diffForHumans(null, false, true)
        '1 點 ago',
        // Carbon::now()->subMinutes(2)->diffForHumans()
        '2 點 ago',
        // Carbon::now()->subMinutes(2)->diffForHumans(null, false, true)
        '2 點 ago',
        // Carbon::now()->subHours(1)->diffForHumans()
        '1 氧 ago',
        // Carbon::now()->subHours(1)->diffForHumans(null, false, true)
        '1 氧 ago',
        // Carbon::now()->subHours(2)->diffForHumans()
        '2 氧 ago',
        // Carbon::now()->subHours(2)->diffForHumans(null, false, true)
        '2 氧 ago',
        // Carbon::now()->subDays(1)->diffForHumans()
        '1 日(曆法) ago',
        // Carbon::now()->subDays(1)->diffForHumans(null, false, true)
        '1 日(曆法) ago',
        // Carbon::now()->subDays(2)->diffForHumans()
        '2 日(曆法) ago',
        // Carbon::now()->subDays(2)->diffForHumans(null, false, true)
        '2 日(曆法) ago',
        // Carbon::now()->subWeeks(1)->diffForHumans()
        '1 星期 ago',
        // Carbon::now()->subWeeks(1)->diffForHumans(null, false, true)
        '1 星期 ago',
        // Carbon::now()->subWeeks(2)->diffForHumans()
        '2 星期 ago',
        // Carbon::now()->subWeeks(2)->diffForHumans(null, false, true)
        '2 星期 ago',
        // Carbon::now()->subMonths(1)->diffForHumans()
        '1 月 ago',
        // Carbon::now()->subMonths(1)->diffForHumans(null, false, true)
        '1 月 ago',
        // Carbon::now()->subMonths(2)->diffForHumans()
        '2 月 ago',
        // Carbon::now()->subMonths(2)->diffForHumans(null, false, true)
        '2 月 ago',
        // Carbon::now()->subYears(1)->diffForHumans()
        '1 夏 ago',
        // Carbon::now()->subYears(1)->diffForHumans(null, false, true)
        '1 夏 ago',
        // Carbon::now()->subYears(2)->diffForHumans()
        '2 夏 ago',
        // Carbon::now()->subYears(2)->diffForHumans(null, false, true)
        '2 夏 ago',
        // Carbon::now()->addSecond()->diffForHumans()
        '1 楚 from now',
        // Carbon::now()->addSecond()->diffForHumans(null, false, true)
        '1 楚 from now',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now())
        '1 楚 after',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), false, true)
        '1 楚 after',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond())
        '1 楚 before',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond(), false, true)
        '1 楚 before',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), true)
        '1 楚',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), true, true)
        '1 楚',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond()->addSecond(), true)
        '2 楚',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond()->addSecond(), true, true)
        '2 楚',
        // Carbon::now()->addSecond()->diffForHumans(null, false, true, 1)
        '1 楚 from now',
        // Carbon::now()->addMinute()->addSecond()->diffForHumans(null, true, false, 2)
        '1 點 1 楚',
        // Carbon::now()->addYears(2)->addMonths(3)->addDay()->addSecond()->diffForHumans(null, true, true, 4)
        '2 夏 3 月 1 日(曆法) 1 楚',
        // Carbon::now()->addYears(3)->diffForHumans(null, null, false, 4)
        '3 夏 from now',
        // Carbon::now()->subMonths(5)->diffForHumans(null, null, true, 4)
        '5 月 ago',
        // Carbon::now()->subYears(2)->subMonths(3)->subDay()->subSecond()->diffForHumans(null, null, true, 4)
        '2 夏 3 月 1 日(曆法) 1 楚 ago',
        // Carbon::now()->addWeek()->addHours(10)->diffForHumans(null, true, false, 2)
        '1 星期 10 氧',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
        '1 星期 6 日(曆法)',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
        '1 星期 6 日(曆法)',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(["join" => true, "parts" => 2])
        '1 星期 and 6 日(曆法) from now',
        // Carbon::now()->addWeeks(2)->addHour()->diffForHumans(null, true, false, 2)
        '2 星期 1 氧',
        // Carbon::now()->addHour()->diffForHumans(["aUnit" => true])
        '1 氧 from now',
        // CarbonInterval::days(2)->forHumans()
        '2 日(曆法)',
        // CarbonInterval::create('P1DT3H')->forHumans(true)
        '1 日(曆法) 3 氧',
    ];
}
